@@ -29,6 +29,9 @@
 #include <GyotoAstrobj.h>
 #include <GyotoThinDisk.h>
 #include <GyotoWorldline.h>
+#include <GyotoThermalSynchrotronSpectrum.h>
+#include <string>
+
 
 namespace Gyoto {
   namespace Astrobj {
@@ -40,11 +43,16 @@ class Gyoto::Astrobj::EquatorialHotSpot
 : public Gyoto::Astrobj::ThinDisk,
   public Gyoto::Worldline {
   friend class Gyoto::SmartPointer<Gyoto::Astrobj::EquatorialHotSpot>;
+
  private:
   double sizespot_;
-  enum beaming_t {IsotropicBeaming=0, NormalBeaming=1, RadialBeaming=2};
+  enum beaming_t {IsotropicBeaming=0, NormalBeaming=1,
+		  RadialBeaming=2, IsotropicConstant=3};
   beaming_t beaming_;
   double beamangle_;
+  SmartPointer<Spectrum::ThermalSynchrotron> spectrumThermalSynch_; // Thermal distribution synchrotron spectrum
+  std::string magneticConfig_; ///< Specify the magnetic field configuration for polarisation
+
  public:
   GYOTO_OBJECT;
   GYOTO_WORLDLINE;
@@ -65,6 +73,9 @@ class Gyoto::Astrobj::EquatorialHotSpot
   void beamAngle(double t);
   double beamAngle() const;
 
+  void magneticConfiguration(std::string config);
+  std::string magneticConfiguration() const;
+
   //
 
   double getMass() const;
@@ -77,6 +88,21 @@ class Gyoto::Astrobj::EquatorialHotSpot
   double emission(double nu_em, double dsem,
 		  state_t const &,
 		  double const coord_obj[8]) const;
+
+  void radiativeQ(double *Inu, double *Qnu, double *Unu,
+		  double *Vnu,
+		  Eigen::Matrix4d *Onu,
+		  double const *nuem , size_t nbnu,
+		  double dsem,
+		  state_t const &cph,
+		  double const *co) const;
+
+  void radiativeQ(double Inu[], // output
+		  double Taunu[], // output
+		  double const nu_ems[], size_t nbnu, // input
+		  double dsem,
+		  state_t const &coord_ph,
+		  double const coord_obj[8]) const;
   
   // needed for legacy XML files
   virtual int setParameter(std::string name,
