@@ -95,14 +95,14 @@ class Gyoto::Metric::KerrBL : public Metric::Generic {
   
   virtual double getPotential(double const pos[4], double l_cst) const;
 
-  void gmunu(double g[4][4], const double * pos) const ;
-  double gmunu(const double * const x, int mu, int nu) const ;
+  void gmunu(double ARGOUT_ARRAY2[4][4], const double IN_ARRAY1[4]) const ;
+  double gmunu(double const x[4], int mu, int nu) const ;
 
   /** 
    * \brief g<SUP>&mu;,&nu;</SUP>
    */
-  void gmunu_up(double gup[4][4], const double * pos) const ;
-  double gmunu_up(const double * const x, int mu, int nu) const ;
+  void gmunu_up(double ARGOUT_ARRAY2[4][4], const double IN_ARRAY1[4]) const ;
+  double gmunu_up(double const x[4], int mu, int nu) const ;
  
   using Generic::christoffel;
   int christoffel(double dst[4][4][4], const double pos[4]) const ;
@@ -165,12 +165,17 @@ class Gyoto::Metric::KerrBL : public Metric::Generic {
    */
   virtual int diff(const double y[8], const double cst[5], 
 		   double res[8]) const ;
+  virtual int diff31(state_t const &x, state_t &dxdt, double mass) const ;
+  /**
+   * Compute lapse and shift at given coordinates
+   */
+  virtual void computeNBeta(const double coord[4],double &NN,double beta[3]) const;//Compute lapse and shift at coord
   /** Integrator. Computes the evolution of y (initcond=y(0)).
    */
   virtual void computeCst(const double coord[8], double cst[5]) const;
  public:
   void setParticleProperties(Worldline* line, const double* coord) const;
-  virtual int isStopCondition(double const * const coord) const;
+  virtual int isStopCondition(double const coord[8]) const;
   
   virtual void observerTetrad(double const pos[4], double fourvel[4],
 			      double screen1[4], double screen2[4],
