@@ -10,7 +10,7 @@
  */
 
 /*
-    Copyright 2011-2016 Frederic Vincent, Thibaut Paumard
+    Copyright 2011-2016, 2018-2020 Frederic Vincent, Thibaut Paumard
 
     This file is part of Gyoto.
 
@@ -166,6 +166,15 @@ class Gyoto::Metric::Generic
   double mass_;     ///< Mass yielding geometrical unit (in kg).
   int coordkind_; ///< Kind of coordinates (cartesian-like, spherical-like, unspecified)
 
+  /**
+   * \brief Whether some virtual methods are implemented
+   *
+   * The default implementations of some methods call
+   * one-another. This member is used internally to avoid infinite
+   * recursion.
+   */
+  int __defaultfeatures;
+
  protected:
   double delta_min_; ///< Minimum integration step for the adaptive integrator
   double delta_max_; ///< Maximum integration step for the adaptive integrator
@@ -187,14 +196,6 @@ class Gyoto::Metric::Generic
   bool keplerian_; ///< 1 if circularVelocity should return the Newtonian Keplerian velocity, in r^-3/2
 
  protected:
-  /**
-   * \brief Set kind_
-   *
-   * kind(const std::string) is protected because, for most Metrics,
-   * it should not be changed in runtime.
-   */
-  void kind(const std::string); ///< Set kind_
-
   /**
    * \brief Set coordkind_
    *
@@ -207,11 +208,11 @@ class Gyoto::Metric::Generic
  public:
   GYOTO_OBJECT;
 
-  const std::string kind() const; ///< Get kind_
   int getRefCount();
   
   // Constructors - Destructor
   // -------------------------
+  Generic();
   Generic(const int coordkind, const std::string &name); ///< Constructor setting Generic::coordkind_ and kind_
   Generic(Generic const &o); ///< Copy constructor
   virtual ~Generic() ;                        ///< Destructor
@@ -220,8 +221,8 @@ class Gyoto::Metric::Generic
   // ---------------------
   virtual Generic * clone() const ; ///< Virtual copy constructor
 
-  void mass(const double);        ///< Set mass used in unitLength()
-  void mass(const double, const std::string &unit);        ///< Set mass used in unitLength()
+  virtual void mass(const double);        ///< Set mass used in unitLength()
+  virtual void mass(const double, const std::string &unit);        ///< Set mass used in unitLength()
 
   // Accessors
 
@@ -437,7 +438,7 @@ class Gyoto::Metric::Generic
    * Compute the dual 1-form of 4-vector.
    * \param IN_ARRAY1_1 4-position;
    * \param IN_ARRAY1_2 quadrivector;
-   * \param[out] ARGOUT_ARRAY3 output 1-form
+   * \param[out] ARGOUT_ARRAY1 output 1-form
    */
   void dualOneForm(double const IN_ARRAY1_1[4], double const IN_ARRAY1_2[4], double ARGOUT_ARRAY1[4]) const ;
 
@@ -502,13 +503,54 @@ class Gyoto::Metric::Generic
    *
    * The default implementation calls double gmunu(const double * x, int mu, int nu) const.
    *
-   * \param[out] g  4x4 array to store the coeefficients
-   * \param[in] x  4-position at which to compute the coefficients;
+   * \param[out] ARGOUT_ARRAY2 (g) 4x4 array to store the coeefficients
+   * \param[in] IN_ARRAY1  (x) 4-position at which to compute the coefficients;
    * \return Metric coefficient g<SUB>&mu;,&nu;</SUB> at point x 
    */
-  virtual void gmunu(double g[4][4], double const pos[4]) const;
+  // Keep argument names for swig!
+  virtual void gmunu(double ARGOUT_ARRAY2[4][4], double const IN_ARRAY1[4]) const;
 
+  /**
+   * \brief Metric contravariant coefficients
+   *
+   * The default implementation calls Metric:: gmunu_up(double g[4][4], const double * pos) const
+   *
+   * \param x  4-position at which to compute the coefficient;
+   * \param mu 1st index of coefficient, 0&le;&mu;&le;3;
+   * \param nu 2nd index of coefficient, 0&le;&nu;&le;3;
+   * \return Metric coefficient g<SUP>&mu;,&nu;</SUP> at point x
+   */
+  virtual double gmunu_up(double const x[4], int mu, int nu) const;
 
+  /**
+   * \brief Metric contravariant coefficients
+   *
+   * The default implementation inverts the covariant coefficients matrix.
+   **/
+  // Keep argument names for swig!
+  virtual void gmunu_up(double ARGOUT_ARRAY2[4][4], const double IN_ARRAY1[4]) const;
+
+  /**
+   * \brief Derivatives of the metric covariant coefficients
+   *
+   * The default implementation evaluates them numerically. The gmunu
+   * matrix is assumed to be symmetrical but no other assumptions are
+   * made at the moment.
+   **/
+  // Keep argument names for swig!
+  virtual void jacobian(double ARGOUT_ARRAY3[4][4][4], const double IN_ARRAY1[4]) const;
+
+  /**
+   * \brief gmunu_up() and jacobian() in one go
+   **/
+  // Keep argument names for swig!
+  virtual void gmunu_up_and_jacobian(double ARGOUT_ARRAY2[4][4], double ARGOUT_ARRAY3[4][4][4], const double IN_ARRAY1[4]) const;
+
+  /**
+   * \brief Computes lapse scalar and shift vector at coord.
+   *
+   **/
+  virtual void computeNBeta(const double coord[4],double &NN,double beta[3]) const;
 
   /**
    * \brief Chistoffel symbol
@@ -569,10 +611,16 @@ class Gyoto::Metric::Generic
   /**
    * \brief F function such as dx/dt=F(x,cst)
    */
-  virtual int diff(state_t const &x, state_t &dxdt) const ;
+  virtual int diff(state_t const &x, state_t &dxdt, double mass) const ;
   /// Obsolete, update your code
+  virtual int diff(state_t const &x, state_t &dxdt)  const = delete;
   virtual int diff(const double y[8], double res[8]) const = delete ;
 
+  /**
+   * \brief F function such as dx/dt=F(x,cst) for 3+1 case
+   */
+  virtual int diff31(state_t const &x, state_t &dxdt, double mass) const ;
+
   /**
    * \brief Set Metric-specific constants of motion. Used e.g. in KerrBL.
    */
