@@ -7,7 +7,7 @@
  */
 
 /*
-    Copyright 2014 Thibaut Paumard
+    Copyright 2014, 2015, 2019-2020 Thibaut Paumard & Frédéric Vincent
 
     This file is part of Gyoto.
 
@@ -60,7 +60,7 @@ class Gyoto::Metric::Minkowski
   Minkowski();
   virtual Minkowski* clone() const ;
 
-  void gmunu(double g[4][4], const double x[4]) const ;
+  void gmunu(double ARGOUT_ARRAY2[4][4], const double IN_ARRAY1[4]) const ;
   int christoffel(double dst[4][4][4], const double x[4]) const ;
 
   // Those two are implemented as examples.
@@ -71,6 +71,10 @@ class Gyoto::Metric::Minkowski
 		      double const pos[4], double fourvel[4],
 		      double screen1[4], double screen2[4], 
 		      double screen3[4]) const;
+
+  // We reimplement diff to be able to integrate Newton's law of motion
+  virtual int diff(state_t const &x, state_t &dxdt, double mass) const ;
+
 };
 
 #endif
