@@ -6,7 +6,7 @@
  */
 
 /*
- *   Copyright (c) 2014-2016, 2018 Frederic Vincent, Thibaut Paumard
+ *   Copyright (c) 2014-2018, 2020 Frederic Vincent, Thibaut Paumard
  *
  *
  */
@@ -52,15 +52,13 @@ class Gyoto::Metric::NumericalMetricLorene
  private:
   char* filename_; ///< Lorene .d data file(s) path
   bool mapet_; ///< Kind of Lorene mapping: 'false' for Map_af, 'true' for Map_et
+  bool axisymCirc_; ///< True if sacetime is axisymmetric and circular
   bool bosonstarcircular_; ///< 1 to implement the circular velocity of a boson star
   int has_surface_; ///< 1 if the metric source has a surface
   int has_acceleration_vector_; ///< 1 if the metric source provides an
                                 ///< acceleration vector
   int specify_marginalorbits_; ///< 1 if marginal orbits are specified in file
   double horizon_; ///< Value of horizon (or any innermost limit)
-  double r_refine_; ///< Refine integration below this r
-  double h0_refine_; ///< Imposed integration step for refined integration
-  int refine_; ///< 1 if refined integration needed
   double initial_time_; ///< Time at which (first) metric is given
   Lorene::Scalar** lapse_tab_;
   Lorene::Vector** shift_tab_;
@@ -111,8 +109,8 @@ class Gyoto::Metric::NumericalMetricLorene
   void specifyMarginalOrbits(bool s);
   bool mapEt() const;
   void mapEt(bool s);
-  std::vector<double> refineIntegStep() const;
-  void refineIntegStep(std::vector<double> const&);
+  bool axisymCirc() const;
+  void axisymCirc(bool s);
 
   Lorene::Vector** getShift_tab() const;
   Lorene::Scalar** getLapse_tab() const;
@@ -137,30 +135,10 @@ class Gyoto::Metric::NumericalMetricLorene
   virtual double getSpecificAngularMomentum(double rr) const;
   virtual double getPotential(double const pos[4], double l_cst) const;
   
-  /**
-   * Runge-Kutta integrator at order 4
-   */
-  virtual int myrk4(double tt, const double coord[7], double h, double res[7]) const;
-  virtual int myrk4(Worldline* line, state_t const &coord, 
-	    double h, state_t &res) const;
-
-  /**
-   * Adaptive Runge-Kutta
-   */
-  int myrk4_adaptive(Gyoto::Worldline* line, state_t const &coord, double lastnorm, double normref, state_t &coordnew, double h0, double& h1, double h1max) const;
-
-  int myrk4_adaptive(double tt, const double coor[7], double lastnorm, double normref, double coornew[7], const double cst[2], double& tdot_used, double h0, double& h1, double& hused, double h1max) const;
-  ///< With energy integration also, coor=[E,r,th,ph,dE/dt,Vr,Vth,Vph]
-
-  /**
-   * Reverse spatial vector if going through 0, without horizon
-   */
-  void reverseR(double tt, double coord[7]) const;
-
   /**
    * Compute lapse and shift at given coordinates
    */
-  void computeNBeta(const double coord[4],double &NN,double beta[3]) const;//Compute lapse and shift at coord
+  virtual void computeNBeta(const double coord[4],double &NN,double beta[3]) const;//Compute lapse and shift at coord
 
   /**
    * 4-Metric
@@ -170,6 +148,21 @@ class Gyoto::Metric::NumericalMetricLorene
 
   double gmunu(const double x[3], int indice_time, int mu, int nu) const ;
 
+  virtual void gmunu_up(double ARGOUT_ARRAY2[4][4], const double IN_ARRAY1[4]) const ;
+
+  void gmunu_up(double gup[4][4], const double x[4], int indice_time) const ;
+
+  void gmunu_di(const double pos[4],
+		double gmunudr[4][4],
+		double gmunudth[4][4]) const ;
+  
+  void gmunu_di(const double pos[4],
+		int indice_time,
+		double gmunudr[4][4],
+		double gmunudth[4][4]) const ;
+
+  virtual void jacobian(double ARGOUT_ARRAY3[4][4][4], const double IN_ARRAY1[4]) const ;
+
   /**
    * \brief r derivative of contravariant 4-metric
    */
@@ -183,18 +176,12 @@ class Gyoto::Metric::NumericalMetricLorene
 		     const int alpha, 
 		     const int mu, const int nu,
 		     const int indice_time) const;
-  virtual int christoffel(double dst[4][4][4], 
+  virtual int christoffel(double dst[4][4][4],
 			  const double coord[4]) const;
-  int christoffel(double dst[4][4][4], 
+  int christoffel(double dst[4][4][4],
 		  const double coord[4],
 		  const int indice_time) const;
-  /**
-   * \brief 3-Christoffels
-   */
-  double christoffel3(const double coord[3], const int indice_time,
-		      const int ii, const int jj, const int kk) const ;
 
-  void setParticleProperties(Worldline * line, const double coord[8]) const;
 
   /**
    * \brief 3rd order interpolation routine
@@ -215,9 +202,10 @@ class Gyoto::Metric::NumericalMetricLorene
    * F function such as d(coord)/d(tau)=F(coord)
    */
   //using Generic::diff;
-  virtual int diff(state_t const &coord, state_t &res) const;
+  virtual int diff(state_t const &coord, state_t &res, double mass) const;
   int diff(double tt, const double y[7], double res[7]) const ;
   virtual int diff(const double y[7], double res[7], int indice_time) const ;
+  virtual int diff31(state_t const &x, state_t &dxdt, double mass) const ;
 
   /**
    * \brief Yield circular velocity at a given position
