@@ -42,6 +42,7 @@ namespace Gyoto{
 #include <GyotoObject.h>
 
 #include <float.h>
+#include <eigen3/Eigen/Dense>
 
 /**
  * \class Gyoto::Photon
@@ -77,6 +78,12 @@ class Gyoto::Photon
    */
   double transmission_freqobs_;
 
+  /// Integrated optical transmission matrix (polarization)
+  /**
+   * At Photon::freq_obs_, between current position and observer.
+   */
+  Eigen::Matrix4d transmissionMatrix_freqobs_;
+
   /// Observer's spectrometer
   /**
    * Conveying observation frequencies for quantities Spectrum and
@@ -91,6 +98,16 @@ class Gyoto::Photon
    */
   double * transmission_;
 
+  /// Nb of crossings of equatorial plane z=0, theta=pi/2
+  int nb_cross_eqplane_;
+
+  /// Integrated optical transmission matrix (polarization)
+  /**
+   * For each frequency in Photon::spectro_->getMidpoints(), between
+   * current position and observer.
+   */
+  Eigen::Matrix4d * transmissionMatrix_;
+
   // Constructors - Destructor
   // -------------------------
 
@@ -143,6 +160,11 @@ class Gyoto::Photon
   /// Get Photon::freq_obs__
   double freqObs() const;
 
+  /// Set Photon::nb_cross_eqplane_
+  void nb_cross_eqplane(int);
+  /// Get Photon::nb_cross_eqplane_
+  int nb_cross_eqplane() const;
+
 
   // Mutators / assignment
   // ---------------------
@@ -266,6 +288,8 @@ class Gyoto::Photon
  public:
   /// Set transmission to 1 for each channel as well as scalar transmission
   void resetTransmission() ;
+  /// Set transmission matrix to identity matrix for each frequency
+  void resetTransmissionMatrix();
 
   /// Get transmission
   /**
@@ -277,6 +301,16 @@ class Gyoto::Photon
    */ 
   double getTransmission(size_t i) const ;
 
+  /// Get transmission matrix
+  /**
+   * Get either Photon::transmission_freqobs_ (with i=-1) or
+   * Photon::transmission_[i].
+   *
+   * \param i channel number of the requested frequency, -1 for
+   * Photon::freq_obs_.
+   */ 
+  Eigen::Matrix4d getTransmissionMatrix(size_t i) const ;
+
   /// Get maximum transmission;
   /**
    * Get current maximum of all the transmissions,
@@ -291,6 +325,11 @@ class Gyoto::Photon
    * getTansmission()[i] == getTransmission(size_t i)
    */
   double const * getTransmission() const ;
+  /// Get Photon::transmissionMatrix_
+  /**
+   * getTansmissionMatrix()[i] == getTransmissionMatrix(size_t i)
+   */
+  Eigen::Matrix4d const * getTransmissionMatrix() const ;
 
   /// Update transmission in a given channel
   /**
@@ -301,15 +340,21 @@ class Gyoto::Photon
    */
   virtual void transmit(size_t i, double t);
 
-  /// Perform one step of radiative transfer
-  virtual void transfer(double * Inu, double * Qnu, double * Unu, double * Vnu,
-			double const * aInu, double const * aQnu,
-			double const * aUnu, double const * aVnu,
-			double const * rQnu, double const * rUnu, double const * rVnu) ;
+  /// Update transmission matrix in a given channel
+  /**
+   * getTransmissionMatrix(size_t i) *= mat.
+   *
+   * \param i channel number. -1 for Matrix Photon::transmissionMatrix_freqobs_.
+   * \param mat transmission Matrix of this fluid element.
+   */
+  virtual void transmit(size_t i, Eigen::Matrix4d mat);
+  virtual void transfer(double * Inu, double * Qnu, double * Unu, double * Vnu, Eigen::Matrix4d * Onu);
+  ///< Perform one step of polarized radiative transfert and update transmission matrix
 
  private:
   /// Allocate Photon::transmission_
   void _allocateTransmission();
+  void _allocateTransmissionMatrix();
 
  public:
   class Refined;
@@ -345,11 +390,10 @@ class Gyoto::Photon::Refined : public Gyoto::Photon {
   ///< Constructor
   virtual void transmit(size_t i, double t);
   ///< Update transmission both in *this and in *parent_
-  virtual void transfer(double * Inu, double * Qnu, double * Unu, double * Vnu,
-			double const * aInu, double const * aQnu,
-			double const * aUnu, double const * aVnu,
-			double const * rQnu, double const * rUnu, double const * rVnu) ;
-  ///< Perform one step of radiative transfer
+  virtual void transmit(size_t i, Eigen::Matrix4d mat);
+  ///< Update transmission Matrix both in *this and in *parent_
+  virtual void transfer(double * Inu, double * Qnu, double * Unu, double * Vnu, Eigen::Matrix4d * Onu);
+  ///< Perform one step of polarized radiative transfert and update transmission matrix
 };
 
 
