@@ -55,6 +55,8 @@ class Gyoto::Spectrum::PowerLawSynchrotron : public Gyoto::Spectrum::Generic {
   double cyclotron_freq_; ///< Cyclotron frequency (e*B / 2*pi*me*c)
   double PLindex_; ///< Power law index: electron spectrum \propto gamma^-PLindex_
   bool angle_averaged_; ///< Boolean for angle averaging
+  double gamma_min_;
+  double gamma_max_;
     
   
 
@@ -97,6 +99,10 @@ class Gyoto::Spectrum::PowerLawSynchrotron : public Gyoto::Spectrum::Generic {
   void PLindex(double ind);
   bool angle_averaged() const;
   void angle_averaged(bool ang);
+  double gamma_min() const;
+  void gamma_min(double gmin);
+  double gamma_max() const;
+  void gamma_max(double gmax);
   
  /**
    * Returns the emission coefficient j_nu in cgs units
@@ -105,22 +111,90 @@ class Gyoto::Spectrum::PowerLawSynchrotron : public Gyoto::Spectrum::Generic {
    * \param nu frequency in Hz
    */
   double jnuCGS(double nu) const;
+  /**
+   * Returns the Stokes Q emission coefficient j_nu in cgs units
+   * i.e. erg cm^-3 s^-1 ster^-1 Hz^-1
+   *
+   * \param nu frequency in Hz
+   */
+  double jQnuCGS(double nu) const;
+  /**
+   * Returns the Stokes U emission coefficient j_nu in cgs units
+   * i.e. erg cm^-3 s^-1 ster^-1 Hz^-1
+   *
+   * \param nu frequency in Hz
+   */
+  double jUnuCGS(double nu) const;
+  /**
+   * Returns the Stokes V emission coefficient j_nu in cgs units
+   * i.e. erg cm^-3 s^-1 ster^-1 Hz^-1
+   *
+   * \param nu frequency in Hz
+   */
+  double jVnuCGS(double nu) const;
+
  /**
    * Returns the absorption coefficient alpha_nu in cgs units [cm^-1]
    *
    * \param nu frequency in Hz
    */
   double alphanuCGS(double nu) const;
+  /**
+   * Returns the Stokes Q absorption coefficient alpha_nu in cgs units [cm^-1]
+   *
+   * \param nu frequency in Hz
+   */
+  double alphaQnuCGS(double nu) const;
+  /**
+   * Returns the Stokes U absorption coefficient alpha_nu in cgs units [cm^-1]
+   *
+   * \param nu frequency in Hz
+   */
+  double alphaUnuCGS(double nu) const;
+  /**
+   * Returns the Stokes V absorption coefficient alpha_nu in cgs units [cm^-1]
+   *
+   * \param nu frequency in Hz
+   */
+  double alphaVnuCGS(double nu) const;
 
   /**
+   * Returns the Stokes Q Faraday rotation coefficient in cgs units [cm^-1]
+   * 
+   *  \param nu frequency in Hz
+   */
+  double rQnuCGS(double nu) const;
+  /**
+   * Returns the Stokes U Faraday rotation coefficient in cgs units [cm^-1]
+   * 
+   *  \param nu frequency in Hz
+   */
+  double rUnuCGS(double nu) const;
+  /**
+   * Returns the Stokes V Faraday rotation coefficient in cgs units [cm^-1]
+   * 
+   *  \param nu frequency in Hz
+   */
+  double rVnuCGS(double nu) const;
+
+   /**
    * Returns the emission and absorption coef in SI
    *
    */
   void radiativeQ(double jnu[], // output
-		  double anu[], // output
-		  double const nu_ems[],
-		  size_t nbnu
-		  ) ;
+        double anu[], // output
+        double const nu_ems[],
+        size_t nbnu
+        ) ;
+  /**
+   * Returns the emission, absorption and Fraday rotation coef in SI for the 4 Stokes parameters
+   *
+   */
+  void radiativeQ(double jInu[], double jQnu[], double jUnu[], double jVnu[],
+        double aInu[], double aQnu[], double aUnu[], double aVnu[],
+        double rQnu[], double rUnu[], double rVnu[],
+        double const nu_ems[],
+        size_t nbnu );
   
 };
 
