@@ -38,6 +38,7 @@ namespace Gyoto{
 #include <GyotoUniformSphere.h>
 #include <GyotoSpectrum.h>
 #include <GyotoWorldline.h>
+#include <GyotoThermalSynchrotronSpectrum.h>
 
 #ifdef GYOTO_USE_XERCES
 #include <GyotoRegister.h>
@@ -97,6 +98,8 @@ class Gyoto::Astrobj::Star :
   
   // Data : 
   // -----
+ private:
+  SmartPointer<Spectrum::ThermalSynchrotron> spectrumThermalSynch_; // Thermal distribution synchrotron spectrum
 
   // Constructors - Destructor
   // -------------------------
@@ -184,6 +187,11 @@ class Gyoto::Astrobj::Star :
 		double * const z, double * const xprime=NULL,
 		double * const yprime=NULL,  double * const zprime=NULL) ;
   virtual void getVelocity(double const pos[4], double vel[4]) ;
+  
+  virtual void radiativeQ(double *Inu, double *Qnu, double *Unu, double *Vnu,
+       Eigen::Matrix4d *Onu,
+       double const *nuem , size_t nbnu, double dsem,
+       state_t const &cph, double const *co) const;
 
 };
 
