@@ -109,7 +109,7 @@ class Gyoto::Spectrum::ThermalBremsstrahlung : public Gyoto::Spectrum::Generic {
    */
   void radiativeQ(double jnu[], // output
 		  double alphanu[], // output
-		  double nu_ems[],
+		  double const nu_ems[],
 		  size_t nbnu
 		  );
 
