@@ -6,7 +6,7 @@
  */
 
 /*
-    Copyright 2012-2017 Frederic Vincent, Thibaut Paumard
+    Copyright 2012-2018 Frederic Vincent, Thibaut Paumard
 
     This file is part of Gyoto.
 
@@ -80,7 +80,7 @@ class Gyoto::Astrobj::ThinDiskPL : public Astrobj::ThinDisk {
  public:
   using ThinDisk::emission;
   virtual double emission(double nu_em, double dsem,
-			  double c_ph[8],double c_obj[8]=NULL) const;
+			  state_t const &c_ph,double const c_obj[8]=NULL) const;
 };
 
 #endif
