@@ -1,21 +1,27 @@
 // include Metric headers
+#include "GyotoComplexMetric.h"
+#include "GyotoShift.h"
 #include "GyotoKerrBL.h"
 #include "GyotoKerrKS.h"
 #include "GyotoMinkowski.h"
 #include "GyotoChernSimons.h"
 #include "GyotoRezzollaZhidenko.h"
 #include "GyotoHayward.h"
+#include "GyotoSchwarzschildHarmonic.h"
 
 // include Astrobj headers
 #include "GyotoComplexAstrobj.h"
 #include "GyotoStar.h"
 #include "GyotoStarTrace.h"
 #include "GyotoFixedStar.h"
+#include "GyotoFreeStar.h"
 #include "GyotoInflateStar.h"
 #include "GyotoTorus.h"
 #include "GyotoOscilTorus.h"
 #include "GyotoThinDisk.h"
+#include "GyotoThinDiskProfile.h"
 #include "GyotoThickDisk.h"
+#include "GyotoSphericalAccretion.h"
 #include "GyotoPageThorneDisk.h"
 #include "GyotoThinDiskPL.h"
 #include "GyotoPolishDoughnut.h"
@@ -32,7 +38,9 @@
 #include "GyotoXillverReflection.h"
 #include "GyotoJet.h"
 #include "GyotoBlob.h"
+#include "GyotoPlasmoid.h"
 #include "GyotoFlaredDiskSynchrotron.h"
+#include "GyotoThinDiskGridIntensity.h"
 
 // include Spectrum headers
 #include "GyotoPowerLawSpectrum.h"
